@@ -3,10 +3,10 @@ import requests
 import json
 from .get_bearer_token import get_bearer_token
 
-def push_software(config_file, fpath, radarType, version_name):
+def push_software(config, fpath, radarType, version_name):
     print('Getting the bearer token...')
-    api_url = config_file['api_url']
-    bearer_token = get_bearer_token(config_file)
+    api_url = config['api_url']
+    bearer_token = get_bearer_token(config)
     headers = {
         'Authorization': 'Bearer ' + bearer_token,
     }
